@@ -15,10 +15,9 @@ use Net::SSH::Perl::Comp;
 use Net::SSH::Perl::Util qw(:hosts);
 use Scalar::Util qw(blessed weaken);
 use Carp qw( croak );
-use Smart::Comments;
 
 use base qw( Net::SSH::Perl );
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Errno qw( EAGAIN EWOULDBLOCK );
 use vars qw( $VERSION $CONFIG $HOSTNAME @PROPOSAL );
@@ -810,61 +809,6 @@ sub _shell {
     $ssh->debug("Entering interactive session.");
 }
 
-#sub open2 {
-#    my $ssh = shift;
-#    my($cmd) = @_;
-#
-#    require Net::SSH::Perl::Handle::SSH2;
-#
-#    my $cmgr = $ssh->channel_mgr;
-#    my $channel = $ssh->_session_channel;
-#    $channel->open;
-#
-#    $channel->register_handler(SSH2_MSG_CHANNEL_OPEN_CONFIRMATION, sub {
-#        my($channel, $packet) = @_;
-#        $channel->{ssh}->debug("Sending command: $cmd");
-#        my $r_packet = $channel->request_start("exec", 1);
-#        $r_packet->put_str($cmd);
-#        $r_packet->send;
-#    });
-#
-#    my $exit;
-#    $channel->register_handler(SSH2_MSG_CHANNEL_REQUEST, sub {
-#    my($channel, $packet) = @_;
-#    my $rtype = $packet->get_str;
-#    my $reply = $packet->get_int8;
-#    $channel->{ssh}->debug("input_channel_request: rtype $rtype reply $reply");
-#    if ($rtype eq "exit-status") {
-#        $exit = $packet->get_int32;
-#    }
-#    if ($reply) {
-#        my $r_packet = $channel->{ssh}->packet_start(SSH2_MSG_CHANNEL_SUCCESS);
-#        $r_packet->put_int($channel->{remote_id});
-#        $r_packet->send;
-#    }
-#    });
-#
-#    my $reply = sub {
-#        my($channel, $packet) = @_;
-#        if ($packet->type == SSH2_MSG_CHANNEL_FAILURE) {
-#            $channel->{ssh}->fatal_disconnect("Request for " .
-#                "exec failed on channel '" . $packet->get_int32 . "'");
-#        }
-#        $channel->{ssh}->break_client_loop;
-#    };
-#
-#    $cmgr->register_handler(SSH2_MSG_CHANNEL_FAILURE, $reply);
-#    $cmgr->register_handler(SSH2_MSG_CHANNEL_SUCCESS, $reply);
-#
-#    $ssh->client_loop;
-#
-#    my $read = Symbol::gensym;
-#    my $write = Symbol::gensym;
-#    tie *$read, 'Net::SSH::Perl::Handle::SSH2', 'r', $channel, \$exit;
-#    tie *$write, 'Net::SSH::Perl::Handle::SSH2', 'w', $channel, \$exit;
-#
-#    return ($read, $write);
-#}
 
 sub break_client_loop { $_[0]->{ek_client_loopcl_quit_pending} = 1 }
 sub restore_client_loop { $_[0]->{_cl_quit_pending} = 0 }
@@ -1033,8 +977,6 @@ AnyEvent::SSH2 - 基于 AnyEvent 的 SSH2 的事件驱动的实现
 
 对多个主机, 并行的远程执行一些命令.
 
-    use Net::SSH::Perl;
-    my $ssh = Net::SSH::Perl->new($host, protocol => 2);
     use AE;
     use AnyEvent::SSH2;
 
@@ -1100,7 +1042,7 @@ AnyEvent::SSH2 - 基于 AnyEvent 的 SSH2 的事件驱动的实现
 
 =head1 DESCRIPTION
 
-这个模块是基于 Net::SSH::Perl 实现的在 AnyEvent 上的事件驱动的支持. 
+这个模块是基于 Net::SSH::Perl 实现的在 AnyEvent 上的事件驱动的支持. 没有使用 Fork 的实现, 这是基于 sock 的原生实现. 
 可以同时异步的连接多个主机进行操作. 
 并且也可以支持同时对一个主机同时执行多条命令.
 
@@ -1146,5 +1088,3 @@ L<AnyEvent>, L<Net::SSH::Perl>
 扶凯 fukai <iakuf@163.com>
 
 =cut
-
-=cut
